#!/usr/bin/env Rscript 

# Load optparse we need to check inputs

suppressPackageStartupMessages(require(optparse))
suppressPackageStartupMessages(require(workflowscriptscommon))

# parse options

option_list = list(
  make_option(
    c("-s", "--samples"),
    action = "store",
    default = NA,
    type = 'character',
    help = "A comma-separated list containing one or more directory names, each corresponding to a 10X sample. Each directory should contain the 'matrix.mtx', 'genes.tsv' and 'barcodes.tsv' files generated by CellRanger. Alternatively, strings may contain a path to a HDF5 file in the sparse matrix format generated by 10X. These can be mixed with directory names when type='auto'."
  ),
  make_option(
    c("-c", "--col-names"),
    action = "store",
    default = FALSE,
    type = 'logical',
    help = "A logical scalar indicating whether the columns of the output object should be named with the cell barcodes."
  ),
  make_option(
    c("-o", "--output-object-file"),
    action = "store",
    default = NA,
    type = 'character',
    help = "File name in which to store serialized SingleCellExperiment object."
  )
)

opt <- wsc_parse_args(option_list, mandatory = c('samples', 'output_object_file'))

# Now we're hapy with the arguments, load DropletUtils and do the work

suppressPackageStartupMessages(require(DropletUtils))

# Parse out multiple directories from the samples string

samples <- wsc_split_string(opt$samples)

# Derive the SingleCellExperiment

single_cell_experiment <- read10xCounts( samples = samples, col.names = opt$col_names  )

# Print an object summary

cat(c(
  '# Object summary', 
  capture.output(print(single_cell_experiment)), 
  '\n# Metadata sample', 
  capture.output(head(colData(single_cell_experiment)))
), 
sep = '\n')

# Output to a serialized R object

saveRDS(single_cell_experiment, file = opt$output_object_file)